# ---------------------------------------------------------------------------
# evaluate_corridor.py
# Created on: Wed Dec 24 2008 10:35:19 AM
#   (generated by ArcGIS/ModelBuilder)
# Usage: evaluate_corridor <Structures_090208> 
# ---------------------------------------------------------------------------

# Import system modules
import sys, string, os, arcpy #arcgisscripting
import functionlib as fl

# Create the Geoprocessor object
#gp = arcgisscripting.create()

# Check out any necessary licenses
arcpy.CheckOutExtension("spatial")

# Script arguments...
pointLayer = arcpy.GetParameterAsText(0)
minCorridorWidth = arcpy.GetParameterAsText(1)
distDistance = arcpy.GetParameterAsText(2)
outRaster = arcpy.GetParameterAsText(3)
cellSize = arcpy.GetParameterAsText(4)
aExtent = arcpy.GetParameterAsText(5)
viewShed = arcpy.GetParameterAsText(6)
elevLayer = arcpy.GetParameterAsText(7)
if aExtent == "" or aExtent == "#":
    desc = arcpy.describe(pointLayer)
    extent = desc.Extent
    aExtent = extent
else:
    arcpy.env.extent = aExtent

# Local variables...

# Process distance inputs...
arcpy.AddMessage("Converting input units to meters...")
width = minCorridorWidth.split(" ")
minCorridorWidth = str(fl.ConvertDistanceToMeters(width[0], width[1]))
del width

distance = distDistance.split(" ")
distDistance = str(fl.ConvertDistanceToMeters(distance[0], distance[1]))
del distance

cell = cellSize.split(" ")
if cellSize == "" or cellSize == "#":
    cellSize = round(float(minCorridorWidth) / 30)
    arcpy.AddMessage("\tCell size set to " + str(cellSize) + " meters...")
else:
    cellSize = str(fl.ConvertDistanceToMeters(cell[0], cell[1]))
del cell

raster = str(outRaster).rsplit("\\",1)
outWorkspace = raster[0]
tWorkspace = fl.CreateTempWorkspace(outWorkspace)
Euc_Dist = tWorkspace + "\\EucDist"
Euc_Dist2 = tWorkspace + "\\EucDist2"
reclassRaster = tWorkspace + "\\Euc_reclass"
Reclass_Focal = tWorkspace + "\\Reclass_Focal"
maxRaster = tWorkspace + "\\Euc_max"
radius = float(minCorridorWidth)/2
InNeighborhood = "CIRCLE " + str(radius) + " MAP"


# Process: Euclidean Distance...
arcpy.AddMessage("Calculating euclidian distance from input structures...")
Euc_Dist = arcpy.sa.EucDistance(pointLayer, "", cellSize, "")
arcpy.AddMessage("Identifying disturbance areas...")
# Reclassify to define disturbed areas...
reclassRaster = arcpy.sa.Reclassify(Euc_Dist, "Value", "0 " + distDistance +" 1", "NODATA")
arcpy.AddMessage("Identifying potential travel areas...")
# Calculate euclidian distance from disturbed areas...
Euc_Dist2 = arcpy.sa.EucDistance(reclassRaster, "", cellSize, "")
# Get focal max within radius equal one half minimum corridor width...
maxRaster = arcpy.sa.FocalStatistics(Euc_Dist2, InNeighborhood, "MAXIMUM", "DATA")
MAX = arcpy.GetRasterProperties_management (Euc_Dist2, "Maximum")
# Reclassify final output. Movement area has focal max >= 1/2 min corridor width...
Reclassification = "0 " + str(radius) + " 0;" + str(radius) + " " + str(MAX) + " 1"
rclss = arcpy.sa.Reclassify(maxRaster, "VALUE", Reclassification, "DATA")

if viewShed == 'true':
    arcpy.AddMessage("Initiating viewshed analysis for travel areas...")
##    vName = outWorkspace + os.sep + raster[1][:7]
    outVShed = tWorkspace + os.sep + "xxvshd"
    arcpy.AddMessage("\tFinding areas hidden from view...")
    outVShed = arcpy.sa.Viewshed(elevLayer, pointLayer)
    output = arcpy.sa.Con(outVShed, "1", rclss, "Value = 0")
    output.save(outRaster)
    
else:
    output = rclss.save(outRaster)
    
# Set output raster as parameter
arcpy.SetParameterAsText(3, outRaster)

# Clean up temporary workspace
fl.CleanFiles(tWorkspace)
arcpy.Delete_management(tWorkspace,"")


